@@ -17,7 +17,6 @@ from namdtools.exceptions import NAMDError
 import namdtools.options as options
 
 import os
-import pandas as pd
 from subprocess import Popen
 
 
@@ -95,7 +94,7 @@ class NAMD:
         # Set the log path
         self._log_path = None
         if configuration_path is not None and log_path is None:
-            log_path = os.path.splitext(configuration_path)[0] + '.log'
+            self.log_path = os.path.splitext(configuration_path)[0] + '.log'
         if log_path is not None:
             self.log_path = log_path
 
@@ -169,9 +168,15 @@ class NAMD:
             NAMD command to run through subprocess.
         """
 
-        if not isinstance(executable, (str, list)):
+        # If executable is a string, crudely split it to list
+        if isinstance(executable, str):
+            executable = executable.split()
+
+        # Make sure we have a list
+        if not isinstance(executable, list):
             raise AttributeError('must be string or list')
 
+        # Set the executable
         self._executable = executable
 
     @property
@@ -196,18 +201,18 @@ class NAMD:
         return None if self._process is None else self._process.poll()
 
     @property
-    def log_(self):
-        pass
-
-    @property
-    def log(self):
+    def log_path(self):
         """
         Logfile
         Returns
         -------
 
         """
-        pass
+        return self._log_path
+
+    @log_path.setter
+    def log_path(self, log_path):
+        self._log_path = log_path
 
     # Start simulations
     def start(self):
@@ -220,8 +225,8 @@ class NAMD:
             raise NAMDError('NAMD already running')
 
         # Open output file and run
-        with open(self.log, 'w') as stream:
-            self._process = Popen(self._executable.append(self._configuration_file), stdout=stream)
+        with open(self._log_path, 'w') as stream:
+            self._process = Popen(self._executable + [self._configuration_path], stdout=stream)
 
         # Should we wait?
         if self._wait:
@@ -294,6 +299,8 @@ def run_namd(configuration_file, log_file, wait=True):
 
 # Extract energy from log file
 def extract_energy(log_file):
+    import pandas as pd
+
     # Initialize DataFrame information
     columns = None
     records = []
@@ -318,15 +325,10 @@ def read_configuration(path):
 
 
 # Compile namd command
-def _compile_namd_executable(strict=True):
+def _compile_namd_executable():
     """
     Compile namd executable to run through subprocess.
 
-    Parameters
-    ----------
-    strict : bool
-        Flag to indicate if we should strictly check that charmrun and namd executables exist.
-
     Returns
     -------
     list
@@ -338,7 +340,12 @@ def _compile_namd_executable(strict=True):
 
     # Add charmrun to command
     if options.charmrun_path is not None:
-        cmd.append(_first_available([options.charmrun_path, 'charmrun']) if strict else options.charmrun_path)
+        paths = [
+            options.charmrun_path,
+            os.path.join(os.getcwd(), 'charmrun'),
+            'charmrun'
+        ]
+        cmd.append(_first_available(paths))
         for arg in options.charmrun_args:
             cmd.append(str(arg))
 
@@ -347,7 +354,14 @@ def _compile_namd_executable(strict=True):
     if options.namd_path is None:
         Warning('what kind of monster sets options.namd to None?')
         options.namd = 'namd'
-    cmd.append(_first_available([options.namd_path, 'namd2.exe', 'namd2']) if strict else options.namd_path)
+    paths = [
+        options.namd,
+        os.path.join(os.getcwd(), 'namd2'),
+        os.path.join(os.getcwd(), 'namd2.exe'),
+        'namd2',
+        'namd2.exe'
+    ]
+    cmd.append(_first_available(paths))
     for arg in options.namd_args:
         cmd.append(str(arg))
 
